@@ -41,8 +41,8 @@ gboolean validate_fd (int           fd,
 char ** document_add_full (int                      *fd,
                            int                      *parent_dev,
                            int                      *parent_ino,
+                           DocumentAddFullFlags     *documents_flags,
                            int                       n_args,
-                           DocumentAddFullFlags      flags,
                            XdpAppInfo               *app_info,
                            const char               *target_app_id,
                            DocumentPermissionFlags   target_perms,
