@@ -137,7 +137,7 @@ static Permission
 get_one_permission (const char *app_id,
                     GVariant   *perms)
 {
-  const char **permissions;
+  g_autofree const char **permissions = NULL;
 
   if (perms == NULL)
     {
@@ -917,7 +917,7 @@ handle_request_background (XdpDbusBackground *object,
 
   impl_request =
     xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (access_impl)),
-                                          G_DBUS_PROXY_FLAGS_NONE,
+                                          G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
                                           g_dbus_proxy_get_name (G_DBUS_PROXY (access_impl)),
                                           request->id,
                                           NULL, &error);
