@@ -150,7 +150,7 @@ device_query_permission_sync (const char *app_id,
         }
 
       impl_request = xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
-                                                           G_DBUS_PROXY_FLAGS_NONE,
+                                                           G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
                                                            g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
                                                            request->id,
                                                            NULL, &error);
@@ -297,7 +297,7 @@ handle_access_device (XdpDbusDevice *object,
   g_object_set_data_full (G_OBJECT (request), "device", g_strdup (devices[0]), g_free);
 
   impl_request = xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
-                                                       G_DBUS_PROXY_FLAGS_NONE,
+                                                       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
                                                        g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
                                                        request->id,
                                                        NULL, &error);
