@@ -76,7 +76,7 @@ send_response_in_thread_func (GTask        *task,
   guint response;
   GVariant *options;
   DocumentFlags flags = DOCUMENT_FLAG_WRITABLE | DOCUMENT_FLAG_DIRECTORY;
-  const char **uris;
+  g_autofree char **uris = NULL;
   GVariant *choices;
   GVariant *current_filter;
   GVariant *writable;
@@ -142,6 +142,8 @@ out:
                                       g_variant_builder_end (&results));
       request_unexport (request);
     }
+
+  g_task_return_boolean (task, TRUE);
 }
 
 /* Calling Lookup on a nonexisting path does not work, so we
@@ -561,7 +563,7 @@ handle_open_file (XdpDbusFileChooser *object,
 
   impl_request =
     xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
-                                          G_DBUS_PROXY_FLAGS_NONE,
+                                          G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
                                           g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
                                           request->id,
                                           NULL, &error);
@@ -727,7 +729,7 @@ handle_save_file (XdpDbusFileChooser *object,
 
   impl_request =
     xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
-                                          G_DBUS_PROXY_FLAGS_NONE,
+                                          G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
                                           g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
                                           request->id,
                                           NULL, &error);
@@ -832,7 +834,7 @@ handle_save_files (XdpDbusFileChooser *object,
 
   impl_request =
     xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
-                                          G_DBUS_PROXY_FLAGS_NONE,
+                                          G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
                                           g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
                                           request->id,
                                           NULL, &error);
